@@ -1,8 +1,13 @@
-from loopr.api.project.categorization_project import CategorizationProject
-from loopr.api.project.object_detection_project import ObjectDetectionProject
-from loopr.api.project.relevancy_project import RelevancyProject
+from loopr.api.project.project import Project
 from loopr.exceptions import LooprInvalidResourceError
-from loopr.resources.constants import INVALID_PROJECT_TYPE
+from loopr.resources.constants import (
+    INVALID_PROJECT_TYPE,
+    categorization_type_project,
+    ner_type_project,
+    object_detection_type_project,
+    ocr_type_project,
+    relevancy_type_project,
+)
 
 
 class ProjectInitializer:
@@ -15,18 +20,18 @@ class ProjectInitializer:
     def __call__(self, project_type):
         """
         Initialize the Project Object with given project_type. (relevancy/object_detection/categorization)
-
         Args:
             project_type (str): DataType of project.
-
         Response:
-            It will return an instance of project of given type.
+            It will return an instance of project.
         """
         try:
             projects = {
-                "relevancy": RelevancyProject,
-                "object_detection": ObjectDetectionProject,
-                "categorization": CategorizationProject,
+                relevancy_type_project: Project,
+                object_detection_type_project: Project,
+                categorization_type_project: Project,
+                ner_type_project: Project,
+                ocr_type_project: Project,
             }
 
             return projects[project_type]
